@@ -82,13 +82,15 @@ private:
   Lum::OS::ColorRef green;
   Lum::OS::ColorRef yellow;
   Lum::OS::ColorRef grey;
+  Status            *status;
 
 public:
-  NetworkModelPainter()
+  NetworkModelPainter(Status *status)
   : red(1,0,0,Lum::OS::display->GetColor(Lum::OS::Display::tableTextColor)),
     green(0,1,0,Lum::OS::display->GetColor(Lum::OS::Display::tableTextColor)),
     yellow(1,0.5,0,Lum::OS::display->GetColor(Lum::OS::Display::tableTextColor)),
-    grey(0.7,0.7,0.7,Lum::OS::display->GetColor(Lum::OS::Display::tableTextColor))
+    grey(0.7,0.7,0.7,Lum::OS::display->GetColor(Lum::OS::Display::tableTextColor)),
+    status(status)
   {
     // no code
   }
@@ -141,7 +143,12 @@ public:
     // Name of network
     //
 
-    draw->PushFont(GetFont());
+    if (network.essid==status->essid) {
+      draw->PushFont(GetFont(),Lum::OS::Font::bold);
+    }
+    else {
+      draw->PushFont(GetFont());
+    }
     draw->PushForeground(GetTextColor(draw));
     draw->DrawString(x+GetFont()->height+
                      Lum::OS::display->GetSpaceHorizontal(Lum::OS::Display::spaceObjectBorder),
@@ -215,6 +222,14 @@ public:
 class MyWindow : public Lum::Dialog
 {
 private:
+#if defined(CAN_USE_STATUS_HILDON)
+    StatusHildon           status;
+#elif defined(CAN_USE_STATUS_LINUX)
+    StatusLinux            status;
+#else
+    StatusNone             status;
+#endif
+
   Lum::Model::StringRef    type;
   Lum::Model::StringRef    essid;
   Lum::Model::StringRef    accesspoint;
@@ -224,7 +239,7 @@ private:
   Lum::Model::StringRef    channel;
   Lum::Model::BooleanRef   powerSaving;
 
-  Lum::Model::IntRef       refreshTime;
+  Lum::Model::ULongRef     refreshTime;
 
   NetworkModelRef          tableModel;
 
@@ -233,6 +248,7 @@ private:
   Lum::Model::BooleanRef   wardrive;
   Lum::Model::ActionRef    powerSavingOnAction;
   Lum::Model::ActionRef    powerSavingOffAction;
+  Lum::Model::ActionRef    showDetailsAction;
 
   Lum::Model::ActionRef    statusTimer;
   Lum::Model::ActionRef    statusErrorTimer;
@@ -243,14 +259,6 @@ private:
   Lum::Model::ActionRef    aboutAction;
   Lum::Model::ActionRef    displayAction;
 
-#if defined(CAN_USE_STATUS_HILDON)
-    StatusHildon           status;
-#elif defined(CAN_USE_STATUS_LINUX)
-    StatusLinux            status;
-#else
-    StatusNone             status;
-#endif
-
   Lum::Audio::PlaySound    *scanNetworkSound;
   Lum::Audio::PlaySound    *openNetworkSound;
 
@@ -513,17 +521,18 @@ public:
     essid(new Lum::Model::String()),
     accesspoint(new Lum::Model::String()),
     client(new Lum::Model::String()),
-    quality(new Lum::Model::Double()),
+    quality(new Lum::Model::Double(0.0,100.0)),
     signalNoise(new Lum::Model::String()),
     channel(new Lum::Model::String()),
     powerSaving(new Lum::Model::Boolean()),
-    refreshTime(new Lum::Model::Int(5)),
+    refreshTime(new Lum::Model::ULong(5,0,10)),
     tableModel(new NetworkModel()),
     scanForNetworks(new Lum::Model::Boolean()),
     signalScan(new Lum::Model::Boolean(false)),
     wardrive(new Lum::Model::Boolean(false)),
     powerSavingOnAction(new Lum::Model::Action()),
     powerSavingOffAction(new Lum::Model::Action()),
+    showDetailsAction(new Lum::Model::Action()),
     statusTimer(new Lum::Model::Action()),
     statusErrorTimer(new Lum::Model::Action()),
     networksTimer(new Lum::Model::Action()),
@@ -534,9 +543,6 @@ public:
     scanNetworkSound(NULL),
     openNetworkSound(NULL)
   {
-    quality->SetRange(0,100);
-    refreshTime->SetRange(0,10);
-
     powerSaving->Disable();
     signalScan->Disable();
     wardrive->Disable();
@@ -546,6 +552,7 @@ public:
     Observe(wardrive);
     Observe(powerSavingOnAction);
     Observe(powerSavingOffAction);
+    Observe(showDetailsAction);
 
     Observe(refreshTime);
     Observe(statusTimer);
@@ -558,7 +565,7 @@ public:
     Observe(aboutAction);
 
     if (Lum::Manager::Display::Instance()!=NULL) {
-      displayAction=Lum::Manager::Display::Instance()	->GetDisplayStateChangeAction();
+      displayAction=Lum::Manager::Display::Instance()->GetDisplayStateChangeAction();
       Observe(displayAction);
     }
 
@@ -608,7 +615,8 @@ public:
     if (scanNetworkSoundPath.Exists()) {
       scanNetworkSound=Lum::Audio::GetPlaySound();
       if (scanNetworkSound!=NULL) {
-        scanNetworkSound->SetFilename(scanNetworkSoundPath.GetPath(),Lum::Audio::PlaySound::typeWav);
+        scanNetworkSound->SetFilename(scanNetworkSoundPath.GetPath(),
+                                      Lum::Audio::PlaySound::typeWav);
       }
     }
 
@@ -710,20 +718,15 @@ public:
 
       headerModel=new Lum::Model::HeaderImpl();
       headerModel->AddColumn(L"Network",Lum::Base::Size::stdCharWidth,15,true);
-      /**
-      headerModel->AddColumn(L"C",Lum::Base::Size::stdCharWidth,2);
-      headerModel->AddColumn(L"Encrypt",Lum::Base::Size::stdCharWidth,7);
-      headerModel->AddColumn(L"Quality",Lum::Base::Size::stdCharWidth,10);*/
 
       table=new Lum::Table();
       table->SetFlex(true,true);
       table->SetHeaderModel(headerModel);
       table->SetModel(tableModel);
-      //table->SetSelection(selection);
-      //table->SetSelectionAction(showDetail);
-      //table->SetDoubleClickAction(showDetail);
+      table->SetSelection(selection);
+      table->SetDefaultAction(showDetailsAction);
       table->SetShowHeader(false);
-      table->SetPainter(new NetworkModelPainter());
+      table->SetPainter(new NetworkModelPainter(&status));
       table->GetTableView()->SetMinHeight(Lum::Base::Size::stdCharHeight,4);
       table->GetTableView()->SetAutoFitColumns(true);
       table->GetTableView()->SetAutoHSize(true);
@@ -817,7 +820,6 @@ public:
       RequestNetworks();
     }
     else if (model==refreshTime && IsOpen()) {
-      std::cout << "Refreshing: " << refreshTime->Get() << std::endl;
       RequestStatus();
     }
     else if (model==status.statusChangedAction &&
@@ -835,7 +837,7 @@ public:
     else if (model==configAction && configAction->IsFinished()) {
       Lum::Def::PropGroup *props=new Lum::Def::PropGroup();
 
-      props->Int(Lum::Def::Int(Lum::Def::Desc(L"Refresh time"), refreshTime));
+      props->Number(Lum::Def::Number(Lum::Def::Desc(L"Refresh time"), refreshTime));
 
       CancelStatus();
 
